<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function pleased_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'pleased-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function pleased_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'pleased-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function pleased_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'pleased-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'pleased_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function pleased_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'pleased-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'pleased-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'pleased-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'pleased-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'pleased-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'pleased-pro' ),
        );

        $output = apply_filters( 'pleased_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'pleased_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function pleased_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'pleased-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'pleased-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'pleased-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'pleased-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'pleased-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'pleased-pro' ),
        );

        $output = apply_filters( 'pleased_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'pleased_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function pleased_pro_site_layout() {
        $pleased_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'pleased_pro_site_layout', $pleased_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function pleased_pro_selected_sidebar() {
        $pleased_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'pleased-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'pleased-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'pleased-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'pleased-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'pleased-pro' ),
        );

        $output = apply_filters( 'pleased_pro_selected_sidebar', $pleased_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'pleased_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function pleased_pro_global_sidebar_position() {
        $pleased_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'pleased_pro_global_sidebar_position', $pleased_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'pleased_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function pleased_pro_sidebar_position() {
        $pleased_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'pleased_pro_sidebar_position', $pleased_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'pleased_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function pleased_pro_pagination_options() {
        $pleased_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'pleased-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'pleased-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'pleased-pro' ),
        );

        $output = apply_filters( 'pleased_pro_pagination_options', $pleased_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function pleased_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'pleased-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'pleased-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'pleased-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'pleased-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'pleased-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'pleased-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'pleased-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'pleased-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'pleased-pro' ),
        );
        return apply_filters( 'pleased_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'pleased_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function pleased_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'pleased-pro' ),
            'off'       => esc_html__( 'Disable', 'pleased-pro' )
        );
        return apply_filters( 'pleased_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'pleased_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function pleased_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'pleased-pro' ),
            'off'       => esc_html__( 'No', 'pleased-pro' )
        );
        return apply_filters( 'pleased_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'pleased_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function pleased_pro_sortable_sections() {
        $sections = array(
            'banner'    => esc_html__( 'Banner', 'pleased-pro' ),
            'about'     => esc_html__( 'About Us', 'pleased-pro' ),
            'gallery'   => esc_html__( 'Gallery', 'pleased-pro' ),
            'package'   => esc_html__( 'Package', 'pleased-pro' ),
            'offer'     => esc_html__( 'Offer', 'pleased-pro' ),
            'service'   => esc_html__( 'Services', 'pleased-pro' ),
            'testimonial' => esc_html__( 'Testimonial', 'pleased-pro' ),
            'blog'      => esc_html__( 'Blog', 'pleased-pro' ),
            'contact'   => esc_html__( 'Contact', 'pleased-pro' ),
        );
        return apply_filters( 'pleased_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'pleased_pro_gallery_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function pleased_pro_gallery_content_type() {
        $pleased_pro_gallery_content_type = array(
            'category'   => esc_html__( 'Category', 'pleased-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $pleased_pro_gallery_content_type = array_merge( $pleased_pro_gallery_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'pleased-pro' ),
                'destination'   => esc_html__( 'Destination', 'pleased-pro' ),
                'activity'      => esc_html__( 'Activity', 'pleased-pro' ),
                ) );
        }

        $output = apply_filters( 'pleased_pro_gallery_content_type', $pleased_pro_gallery_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_package_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function pleased_pro_package_content_type() {
        $pleased_pro_package_content_type = array(
            'category'  => esc_html__( 'Category', 'pleased-pro' ),
            'page'      => esc_html__( 'Page', 'pleased-pro' ),
            'post'      => esc_html__( 'Post', 'pleased-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $pleased_pro_package_content_type = array_merge( $pleased_pro_package_content_type, array(
                'trip'          => esc_html__( 'Trip', 'pleased-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'pleased-pro' ),
                'destination'   => esc_html__( 'Destination', 'pleased-pro' ),
                'activity'      => esc_html__( 'Activity', 'pleased-pro' ),
                ) );
        }

        $output = apply_filters( 'pleased_pro_package_content_type', $pleased_pro_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_offer_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function pleased_pro_offer_content_type() {
        $pleased_pro_offer_content_type = array(
            'category'  => esc_html__( 'Category', 'pleased-pro' ),
            'page'      => esc_html__( 'Page', 'pleased-pro' ),
            'post'      => esc_html__( 'Post', 'pleased-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $pleased_pro_offer_content_type = array_merge( $pleased_pro_offer_content_type, array(
                'trip'          => esc_html__( 'Trip', 'pleased-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'pleased-pro' ),
                'destination'   => esc_html__( 'Destination', 'pleased-pro' ),
                'activity'      => esc_html__( 'Activity', 'pleased-pro' ),
                ) );
        }

        $output = apply_filters( 'pleased_pro_offer_content_type', $pleased_pro_offer_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_blog_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function pleased_pro_blog_content_type() {
        $pleased_pro_blog_content_type = array(
            'category'  => esc_html__( 'Category', 'pleased-pro' ),
            'page'      => esc_html__( 'Page', 'pleased-pro' ),
            'post'      => esc_html__( 'Post', 'pleased-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $pleased_pro_blog_content_type = array_merge( $pleased_pro_blog_content_type, array(
                'trip'          => esc_html__( 'Trip', 'pleased-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'pleased-pro' ),
                'destination'   => esc_html__( 'Destination', 'pleased-pro' ),
                'activity'      => esc_html__( 'Activity', 'pleased-pro' ),
                ) );
        }

        $output = apply_filters( 'pleased_pro_blog_content_type', $pleased_pro_blog_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_service_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function pleased_pro_service_content_type() {
        $pleased_pro_service_content_type = array(
            'category'  => esc_html__( 'Category', 'pleased-pro' ),
            'page'      => esc_html__( 'Page', 'pleased-pro' ),
            'post'      => esc_html__( 'Post', 'pleased-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $pleased_pro_service_content_type = array_merge( $pleased_pro_service_content_type, array(
                'trip'          => esc_html__( 'Trip', 'pleased-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'pleased-pro' ),
                'destination'   => esc_html__( 'Destination', 'pleased-pro' ),
                'activity'      => esc_html__( 'Activity', 'pleased-pro' ),
                ) );
        }

        $output = apply_filters( 'pleased_pro_service_content_type', $pleased_pro_service_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'pleased_pro_banner_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function pleased_pro_banner_content_type() {
        $pleased_pro_banner_content_type = array(
            'category'  => esc_html__( 'Category', 'pleased-pro' ),
            'page'      => esc_html__( 'Page', 'pleased-pro' ),
            'post'      => esc_html__( 'Post', 'pleased-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $pleased_pro_banner_content_type = array_merge( $pleased_pro_banner_content_type, array(
                'trip'          => esc_html__( 'Trip', 'pleased-pro' ),
                ) );
        }

        $output = apply_filters( 'pleased_pro_banner_content_type', $pleased_pro_banner_content_type );


        return $output;
    }
endif;